/////////////////////////////////////////////////////////
//        Mouse support library  (header file)         //
// Authors:                                            //
//    Alex V. Boreskoff   &  (C) Skvortsov Artyom      //
//                  Errors free !                      //
/////////////////////////////////////////////////////////


#ifndef __MOUSE__
#define __MOUSE__

const MOUSE_MOVE_MASK       =  0x01;    // For mouse handler
const MOUSE_LBUTTON_PRESS   =  0x02;
const MOUSE_LBUTTON_RELEASE =  0x04;
const MOUSE_RBUTTON_PRESS   =  0x08;
const MOUSE_RBUTTON_RELEASE =  0x10;
const MOUSE_MBUTTON_PRESS   =  0x20;
const MOUSE_MBUTTON_RELEASE =  0x40;
const MOUSE_ALL_EVENTS      =  0x7F;

const LEFTPRESS    = 0x01;                // For 'ReadMouseState' function
const RIGHTPRESS   = 0x02;
const MIDDLEPRESS  = 0x04;

enum MOUSEPRESS { MSLEFT, MSRIGHT, MSMIDDLE };  // For 'MousePress' function

struct  MouseState
{
int x, y;
int Buttons;
};

struct  CursorShape
{
unsigned AndMask[16];
unsigned XorMask[16];
int HotX, HotY;
};

typedef void    ( *MouseHandler )( int, int, int, int );

int     ResetMouse (void);
void    ShowMouseCursor (void);
void    HideMouseCursor (void);
void    ReadMouseState ( MouseState& );
void    MoveMouseCursor ( int x, int y );
void    SetHorzMouseRange ( int xmin, int xmax );
void    SetVertMouseRange ( int ymin, int ymax );
void    SetMouseShape ( CursorShape& );
void    SetHideRange ( int x1, int y1, int x2, int y2 );
void    SetMouseHandler ( MouseHandler, int = MOUSE_ALL_EVENTS );
void    RemoveMouseHandler (void);
void    SetMouseShowPage (int page);
int     GetMouseShowPage (void);
void    MousePress( MouseState& );    //  ####.Buttons -  (p) 
void    MouseMove(MouseState& );
void    MikkyCorrect( MouseState& );

#define ClearHideRange()       ShowMouseCursor()

#endif
//===========================END=OF=FILE================================
